@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir-indicator.h"
 #include "gnome-cmd-style.h"
@@ -31,7 +33,7 @@
 using namespace std;
 
 
-struct _GnomeCmdDirIndicatorPrivate
+struct GnomeCmdDirIndicatorPrivate
 {
     GtkWidget *event_box;
     GtkWidget *label;
@@ -91,20 +93,20 @@ static gboolean on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator, GdkEv
         const gchar *labelText = gtk_label_get_text (GTK_LABEL (indicator->priv->label));
         gchar *chTo = g_strdup(labelText);
         gint x = (gint) event->x;
-        gint i;
 
-        for (i = 0; i < indicator->priv->numPositions; i++)
+        for (gint i = 0; i < indicator->priv->numPositions; i++)
             if (x < indicator->priv->slashPixelPosition[i])
             {
                 strncpy (chTo, labelText, indicator->priv->slashCharPosition[i]);
                 chTo[indicator->priv->slashCharPosition[i]] = 0x0;
                 gnome_cmd_main_win_switch_fs (main_win, fs);
-                gnome_cmd_file_selector_goto_directory (fs, chTo);
+                fs->goto_directory(chTo);
                 g_free (chTo);
                 return TRUE;
             }
 
         // pointer is after directory name - just return
+        g_free (chTo);
         return TRUE;
     }
 
@@ -275,7 +277,7 @@ static void on_dir_history_item_selected (GtkMenuItem *item, const gchar *path)
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
     gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    gnome_cmd_file_selector_goto_directory (indicator->priv->fs, path);
+    indicator->priv->fs->goto_directory(path);
 }
 
 
@@ -288,7 +290,7 @@ static void on_bookmark_item_selected (GtkMenuItem *item, GnomeCmdBookmark *bm)
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
     gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    gnome_cmd_file_selector_goto_directory (indicator->priv->fs, bm->path);
+    indicator->priv->fs->goto_directory(bm->path);
 }
 
 
@@ -296,7 +298,7 @@ static void get_popup_pos (GtkMenu *menu, gint *x, gint *y, gboolean push_in, Gn
 {
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
-    GtkWidget *w = GTK_WIDGET (indicator->priv->fs->list);
+    GtkWidget *w = GTK_WIDGET (indicator->priv->fs->file_list());
 
     gdk_window_get_origin (w->window, x, y);
 }
@@ -331,7 +333,7 @@ static void popup_dir_history (GnomeCmdDirIndicator *indicator)
         GTK_OBJECT (indicator->priv->dir_history_popup), "hide",
         GTK_SIGNAL_FUNC (on_dir_history_popup_hide), indicator);
 
-    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
     History *history = gnome_cmd_con_get_dir_history (con);
 
     for (GList *l=history->ents; l; l=l->next)
@@ -344,7 +346,7 @@ static void popup_dir_history (GnomeCmdDirIndicator *indicator)
                        path);
     }
 
-    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup, (GtkMenuPositionFunc)get_popup_pos, indicator, NULL, NULL, NULL);
+    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
 
     gint w = -1;
 
@@ -357,14 +359,14 @@ static void popup_dir_history (GnomeCmdDirIndicator *indicator)
 
 static void on_bookmarks_add_current (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
 {
-    GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (indicator->priv->fs);
-    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
+    GnomeCmdFile *f = GNOME_CMD_FILE (indicator->priv->fs->get_directory());
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
     GnomeCmdBookmark *bm = g_new0 (GnomeCmdBookmark, 1);
 
-    bm->name = g_strdup (gnome_cmd_file_get_name (GNOME_CMD_FILE (dir)));
-    bm->path = gnome_cmd_file_get_path (GNOME_CMD_FILE (dir));
+    bm->name = g_strdup (gnome_cmd_file_get_name (f));
+    bm->path = gnome_cmd_file_get_path (f);
     bm->group = group;
 
     group->bookmarks = g_list_append (group->bookmarks, bm);
@@ -386,7 +388,7 @@ inline void popup_bookmarks (GnomeCmdDirIndicator *indicator)
     gtk_object_set_data_full (GTK_OBJECT (indicator), "bookmark_popup", indicator->priv->bookmark_popup, (GtkDestroyNotify) gtk_widget_unref);
     gtk_signal_connect (GTK_OBJECT (indicator->priv->bookmark_popup), "hide", GTK_SIGNAL_FUNC (on_bookmark_popup_hide), indicator);
 
-    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
+    GnomeCmdCon *con = indicator->priv->fs->get_connection();
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
     for (GList *l = group->bookmarks; l; l = l->next)
@@ -403,7 +405,7 @@ inline void popup_bookmarks (GnomeCmdDirIndicator *indicator)
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Add current dir"), GTK_SIGNAL_FUNC (on_bookmarks_add_current), indicator);
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Manage bookmarks..."), GTK_SIGNAL_FUNC (on_bookmarks_manage), indicator);
 
-    gnome_popup_menu_do_popup (indicator->priv->bookmark_popup, (GtkMenuPositionFunc)get_popup_pos, indicator, NULL, NULL, NULL);
+    gnome_popup_menu_do_popup (indicator->priv->bookmark_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
 
     gint w = -1;
 
@@ -430,9 +432,9 @@ static void init (GnomeCmdDirIndicator *indicator)
     // create the directory label and its event box
     indicator->priv->event_box = gtk_event_box_new ();
     gtk_widget_ref (indicator->priv->event_box);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "motion_notify_event",
+    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "motion-notify-event",
                                GTK_SIGNAL_FUNC (on_dir_indicator_motion), indicator);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "leave_notify_event",
+    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "leave-notify-event",
                                GTK_SIGNAL_FUNC (on_dir_indicator_leave), indicator);
     gtk_widget_set_events (indicator->priv->event_box, GDK_POINTER_MOTION_MASK);
 
@@ -445,7 +447,7 @@ static void init (GnomeCmdDirIndicator *indicator)
     indicator->priv->history_button = gtk_button_new ();
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->history_button, GTK_CAN_FOCUS);
     gtk_widget_ref (indicator->priv->history_button);
-    gtk_button_set_relief (GTK_BUTTON (indicator->priv->history_button), gnome_cmd_data_get_button_relief ());
+    gtk_button_set_relief (GTK_BUTTON (indicator->priv->history_button), gnome_cmd_data.button_relief);
     gtk_object_set_data_full (GTK_OBJECT (indicator),
                               "button", indicator->priv->history_button,
                               (GtkDestroyNotify) gtk_widget_unref);
@@ -460,7 +462,7 @@ static void init (GnomeCmdDirIndicator *indicator)
     // create the bookmark popup button
     indicator->priv->bookmark_button = create_styled_pixmap_button (NULL, IMAGE_get_gnome_cmd_pixmap (PIXMAP_BOOKMARK));
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->bookmark_button, GTK_CAN_FOCUS);
-    gtk_button_set_relief (GTK_BUTTON (indicator->priv->bookmark_button), gnome_cmd_data_get_button_relief ());
+    gtk_button_set_relief (GTK_BUTTON (indicator->priv->bookmark_button), gnome_cmd_data.button_relief);
     gtk_object_set_data_full (GTK_OBJECT (indicator), "button", indicator->priv->bookmark_button, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (indicator->priv->bookmark_button);
 
@@ -481,7 +483,7 @@ static void init (GnomeCmdDirIndicator *indicator)
 /***********************************
  * Public functions
  ***********************************/
-GtkType gnome_cmd_dir_indicator_get_type (void)
+GtkType gnome_cmd_dir_indicator_get_type ()
 {
     static GtkType type = 0;
 
@@ -509,7 +511,7 @@ GtkWidget *gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 {
     GnomeCmdDirIndicator *dir_indicator = (GnomeCmdDirIndicator *) gtk_type_new (gnome_cmd_dir_indicator_get_type ());
 
-    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button_press_event", G_CALLBACK (on_dir_indicator_clicked), fs);
+    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button-press-event", G_CALLBACK (on_dir_indicator_clicked), fs);
 
     dir_indicator->priv->fs = fs;
 
@@ -533,7 +535,7 @@ void gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *pa
     if (!path)
         return;
 
-    gboolean isUNC = g_str_has_prefix(path,"\\\\");
+    gboolean isUNC = g_str_has_prefix (path, "\\\\");
 
     if (!isUNC && *path!=G_DIR_SEPARATOR)
         return;
