@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,26 +31,24 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_make_copy_dialog_get_type ())
 
 
-typedef struct _GnomeCmdMakeCopyDialog GnomeCmdMakeCopyDialog;
-typedef struct _GnomeCmdMakeCopyDialogPrivate GnomeCmdMakeCopyDialogPrivate;
-typedef struct _GnomeCmdMakeCopyDialogClass GnomeCmdMakeCopyDialogClass;
+struct GnomeCmdMakeCopyDialogPrivate;
 
 
-struct _GnomeCmdMakeCopyDialog
+struct GnomeCmdMakeCopyDialog
 {
     GnomeCmdStringDialog parent;
     GnomeCmdMakeCopyDialogPrivate *priv;
 };
 
 
-struct _GnomeCmdMakeCopyDialogClass
+struct GnomeCmdMakeCopyDialogClass
 {
     GnomeCmdStringDialogClass parent_class;
 };
 
 
-GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *finfo, GnomeCmdDir *dir);
+GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *f, GnomeCmdDir *dir);
 
-GtkType gnome_cmd_make_copy_dialog_get_type (void);
+GtkType gnome_cmd_make_copy_dialog_get_type ();
 
 #endif // __GNOME_CMD_MAKE_COPY_DIALOG_H__
