@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-quicksearch-popup.h"
 #include "gnome-cmd-file-list.h"
@@ -30,7 +32,7 @@ using namespace std;
 
 static GtkWindowClass *parent_class = NULL;
 
-struct _GnomeCmdQuicksearchPopupPrivate
+struct GnomeCmdQuicksearchPopupPrivate
 {
     GnomeCmdFileList *fl;
 
@@ -40,13 +42,13 @@ struct _GnomeCmdQuicksearchPopupPrivate
 };
 
 
-inline void focus_file (GnomeCmdQuicksearchPopup *popup, GnomeCmdFile *finfo)
+inline void focus_file (GnomeCmdQuicksearchPopup *popup, GnomeCmdFile *f)
 {
-    if (strcmp (finfo->info->name, "..") == 0)
+    if (strcmp (f->info->name, "..") == 0)
         return;
 
-    popup->priv->last_focused_file = finfo;
-    gint row = gnome_cmd_file_list_get_row_from_file (popup->priv->fl, finfo);
+    popup->priv->last_focused_file = f;
+    gint row = popup->priv->fl->get_row_from_file(f);
     gtk_clist_moveto (GTK_CLIST (popup->priv->fl), row, 0, 1, 0);
     gtk_clist_freeze (GTK_CLIST (popup->priv->fl));
     GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row = row;
@@ -71,25 +73,25 @@ static void set_filter (GnomeCmdQuicksearchPopup *popup, const gchar *text)
         popup->priv->matches = NULL;
     }
 
-    for (GList *files = gnome_cmd_file_list_get_all_files (popup->priv->fl); files; files = files->next)
+    for (GList *files = popup->priv->fl->get_visible_files(); files; files = files->next)
     {
-        GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
+        GnomeCmdFile *f = (GnomeCmdFile *) files->data;
         gint res;
 
-        if (gnome_cmd_data_get_case_sens_sort ())
-            res = strncmp (finfo->info->name, text, strlen(text));
+        if (gnome_cmd_data.case_sens_sort)
+            res = strncmp (f->info->name, text, strlen(text));
         else
-            res = strncasecmp (finfo->info->name, text, strlen(text));
+            res = strncasecmp (f->info->name, text, strlen(text));
 
         if (res == 0)
         {
             if (first)
             {
-                focus_file (popup, finfo);
+                focus_file (popup, f);
                 first = FALSE;
             }
 
-            popup->priv->matches = g_list_append (popup->priv->matches, finfo);
+            popup->priv->matches = g_list_append (popup->priv->matches, f);
         }
     }
 
@@ -126,24 +128,31 @@ static void on_text_changed (GtkEntry *entry, GnomeCmdQuicksearchPopup *popup)
 
 static gboolean on_key_pressed (GtkWidget *entry, GdkEventKey *event, GnomeCmdQuicksearchPopup *popup)
 {
+    if (GTK_ENTRY (entry)->editable && event->type == GDK_KEY_PRESS)
+        if (gtk_im_context_filter_keypress (GTK_ENTRY (entry)->im_context, event))
+            return TRUE;
+
     // While in quicksearch, treat "ALT/CTRL + key" as a simple "key"
     event->state &= ~(GDK_CONTROL_MASK | GDK_MOD1_MASK);
 
     switch (event->keyval)
     {
         case GDK_Escape:
-        case GDK_Return:
-            gnome_cmd_file_list_select_row (popup->priv->fl, GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row);
+            popup->priv->fl->select_row(GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row);
             hide_popup (popup);
             return TRUE;
 
+        // for more convenience do ENTER action directly on the current quicksearch item
+        case GDK_Return:
+        case GDK_KP_Enter:
+
         // for more convenience jump direct to Fx function on the current quicksearch item
         case GDK_F3:
         case GDK_F4:
         case GDK_F5:
         case GDK_F6:
         case GDK_F8:
-            gnome_cmd_file_list_select_row (popup->priv->fl, GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row);
+            popup->priv->fl->select_row(GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row);
             hide_popup (popup);
             gnome_cmd_main_win_keypressed (main_win, event);
             return TRUE;
@@ -289,7 +298,7 @@ static void init (GnomeCmdQuicksearchPopup *popup)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_quicksearch_popup_get_type (void)
+GtkType gnome_cmd_quicksearch_popup_get_type ()
 {
     static GtkType type = 0;
 
